%%          Matlab Tutorial. M.Sc in Finance a.y. 2013-2014              %%
%                          Course: 20192                                  %

%{
Useful websites and tutorials:
- http://www.mathworks.com/matlabcentral/
- http://www.mathworks.com/help/pdf_doc/matlab/getstart.pdf
- http://www.kevinsheppard.com/images/5/56/MATLAB_Notes_2013.pdf
%}

clear all;
close all;

%{
Remeber to set the path to the folder where all your files are (if you did
not do it manually)
- path('newpath') changes the search path to newpath, where newpath is a string array of folders
- addpath(folderName1,...,folderNameN) adds the specified folders to the top of the search path.
%}

%% Variable definition
%matrix -> capital letter; vector -> lower-case letter
 
v = [1 2 3 4] %row vector
v = [1; 2; 3; 4] %column vector
v = [1 2 3 4]' %column vector
v = 1:0.5:10
v = 1:10 %default step: 1, row vector
 
M = [1 2 3; 4 5 6; 7 8 9]

M = zeros(3,2) %1 number: square; 2 number: rectangular
M = eye(3) %identity matrix
M = ones(3) %squared matrix of ones, with dimension 3
k = 0;
M = diag([1:3],k) %k = 0 main diagonal, k>0 above main diagonal, k<0 below main diagonal
M = random('norm',0,1,5,5) %Choose the distribution and parameters

%Matrix manipulation
%Access to matrix entry
ss = size(M) 
c = M(:,1) %first column
r = M(1,:) %first row
cs = M(:,1:2) %first 2 colums
rs = M(1:2,:) %first 2 rows
rc = M(1:2,1:2) %submatrix 2x2 (upper left)
%Diagonals
d = diag(M) %main diagonal as column vector
l = tril(M,0) %lower triangular matrix k index as before
u = triu(M,0)

%Specific values
%Linear index
find(M>1) %output in linear index
M(find(M>1)) %output in elements
%Logic index
M>1 %output logical index, 1 = true, 0 = false
M(M>1) %output in elements: equal to M(find(M>1))
%Single matrix manipulation
X = [1 2;3 4]
X(3,3) = 2 %add scalar in a specific position
M = [X [1; 2; 3]] %add column
M = [M; [1:5:16]] %add row
M = M(1:3,:) %delete row
M = M(:,1:3) %delete column
M1 = [1 2;3 4]
M2 = [5 6;7 8]
Mhoriz = [M1 M2] 
Mvert = [M1; M2]
Mblok = blkdiag(M1, M2) %block diagonal matrix
I = inv(X) %also useful: trace(X), det(X) or rank(X)

%Matrix operations
M1' %transpose
M1/M2 %M1 divided by M2
M1/M2 - M1*inv(M2) %check
M1\M2 %M2 divided by M1
M1\M2 - inv(M1)*M2 %check

%Element-wise operations
M1.*M2
M1./M2
M1.\M2
M1.^M2

%% Data import and visualization

%XLS import
[data,textdata,raw] = xlsread('STOCKINT2013.xls','Quarterly'); 
%xlsread: specify sheet, then range specify where to put the text and the data
%textread, csvread, dlmread and others are also available

%Convert dates
date=datenum(textdata(4:end,1),'dd/mm/yyyy'); %in this way we have numerical format of dates which is different from xls numerical format of dates
%notice that we start transforming after the 4th row!
f1='31/03/1974';
f2='31/12/2011';
date_find1=datenum(f1,'dd/mm/yyyy');
date_find2=datenum(f2,'dd/mm/yyyy');
first=datefind(date_find1,date);
last=datefind(date_find2,date); 

%Look at UK stock price index
UK.lp=log(data(first:last,5));
stats = [mean(UK.lp);std(UK.lp);skewness(UK.lp);kurtosis(UK.lp)]

%Plot
figure(1);
plot(date(first:last),UK.lp,'r');
datetick('x','yyyy','keeplimits'); %Label the x-axis with 4-digit years
title('Log Price of UK stock market index')
xlabel('Year');

%% Regression

%Regress log(price) on its lag
%take as a reference the linear model Y=b*X + error

n=size(UK.lp,1)-1;
X = [ones(n,1) UK.lp(1:end-1,:)]; %the model has a constant
Y = UK.lp(2:end,:);    
b = inv(X'*X)*(X'*Y); %coefficients
e = Y - X*b; %residuals
SSr = e'*e; % residual sum of squares
SStot = (length(Y)-1)*var(Y); % total sum of squares
rsq = 1 - SSr/SStot; %coefficient of determination
%alternatively
[b bint e rint stats] = regress(UK.lp(2:end,:),[ones(n,1) UK.lp(1:end-1,:)]);

%check out now how log(lp_t)-log(lp_t-1) looks like:
figure(2)
plot(diff(UK.lp))

%% Functions and Flow Control

%Computation of dividends at a yearly horizon

%Rememeber that the excel file had quarterly dividend yield in column 7
UK.d=data(first:last,7).*(data(first:last,5)/100);

%Suppose we want to filter out some variation
%call function for (simple) moving average with a time period of 4 (quarterly data)
UK.da=SMA(UK.d,4); %open the file SMA.m in the current folder and check it out

%equivalently we could have done:
UK.da2=NaN(size(UK.d,1),1);
UK.da2(4:end,:)=(UK.d(4:end,:)+UK.d(3:end-1,:)+UK.d(2:end-2,:)+UK.d(1:end-3,:))/4;

figure(3)
plot(UK.d,'r')
hold on
plot (UK.da,'g')


